@@ -134,7 +134,7 @@ xf86freeModeLineList (XF86ConfModeLinePtr ptr)
 		TestFree (ptr->ml_comment);
 		prev = ptr;
 		ptr = ptr->list.next;
-		xf86conffree (prev);
+		free (prev);
 	}
 }
 
@@ -580,7 +580,7 @@ VertDone:
 
 				/* add to the end of the list of modes sections 
 				   referenced here */
-				mptr = xf86confcalloc (1, sizeof (XF86ConfModesLinkRec));
+				mptr = calloc (1, sizeof (XF86ConfModesLinkRec));
 				mptr->list.next = NULL;
 				mptr->ml_modes_str = val.str;
 				mptr->ml_modes = NULL;
@@ -688,8 +688,6 @@ xf86printMonitorSection (FILE * cf, XF86ConfMonitorPtr ptr)
 			fprintf (cf, "\tDisplaySize  %d\t%d\n",
 					 ptr->mon_width,
 					 ptr->mon_height);
-		if ( ptr->mon_n_hsync || ptr->mon_n_vrefresh )
-		    fprintf(cf," ### Comment all HorizSync and VertRefresh values to use DDC:\n");
 		for (i = 0; i < ptr->mon_n_hsync; i++)
 		{
 			fprintf (cf, "\tHorizSync    %2.1f - %2.1f\n",
@@ -824,7 +822,7 @@ xf86freeMonitorList (XF86ConfMonitorPtr ptr)
 		xf86freeModeLineList (ptr->mon_modeline_lst);
 		prev = ptr;
 		ptr = ptr->list.next;
-		xf86conffree (prev);
+		free (prev);
 	}
 }
 
@@ -840,7 +838,7 @@ xf86freeModesList (XF86ConfModesPtr ptr)
 		xf86freeModeLineList (ptr->mon_modeline_lst);
 		prev = ptr;
 		ptr = ptr->list.next;
-		xf86conffree (prev);
+		free (prev);
 	}
 }
 
